<?php
/**
 * A filter for validating the refill request
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 Ship-Simu Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class ShipSimuUserStatusGuestFilter extends BaseShipSimuFilter implements Filterable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this filter class
	 *
	 * @return	$filterInstance		An instance of this filter class
	 */
	public static final function createShipSimuUserStatusGuestFilter () {
		// Get a new instance
		$filterInstance = new ShipSimuUserStatusGuestFilter();

		// Return the instance
		return $filterInstance;
	}

	/**
	 * Executes the filter with given request and response objects
	 *
	 * @param	$requestInstance	An instance of a class with an Requestable interface
	 * @param	$responseInstance	An instance of a class with an Responseable interface
	 * @return	void
	 * @todo	Maybe we need to added some more generic tests on the request here?
	 * @throws	FilterChainException	If this filter fails to operate
	 */
	public function execute (Requestable $requestInstance, Responseable $responseInstance) {
		// Execute the parent execute method
		parent::execute($requestInstance, $responseInstance);

		// Get a user instance for comparison
		$userInstance = Registry::getRegistry()->getInstance('user');

		// Is the user account confirmed?
		if ($userInstance->getField(UserDatabaseWrapper::DB_COLUMN_USER_STATUS) == $this->getConfigInstance()->getConfigEntry('user_status_guest')) {
			// Request is invalid!
			$requestInstance->requestIsValid(false);

			// Redirect to configured URL
			$responseInstance->redirectToConfiguredUrl('login_user_status_guest');

			// Stop processing here
			exit();
		} // END - if
	}
}

// [EOF]
?>
